# winnie

<!-- Remember to change the URL from winnie to the name of your project -->
![Tests](https://github.com/HWRacing/winnie/actions/workflows/tests.yml/badge.svg)

A library for the CAN calibration protocol
